==> devicely-1.0.1.tar.gz: devicely-1.0.1/README.md <==
[![Actions Status: test](https://github.com/hpi-dhc/devicely/workflows/test/badge.svg)](https://github.com/hpi-dhc/devicely/actions/workflows/test.yml)
![Coverage Badge](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/jostmorgenstern/270a0114dfad9251945a146dd6d29fa6/raw/devicely_coverage_main.json)
[![DOI](https://zenodo.org/badge/279395106.svg)](https://zenodo.org/badge/latestdoi/{279395106})
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)

![Devicely Logo](/imgs/logo/devicely-logo.png)

devicely is a Python package for reading, anonymizing and writing data from various health monitoring sensors.
With devicely, you can read sensor data and have it easily accessible in dataframes.
You can also anonymize data and write it back using the original data format. This makes it convenient to share health sensor data with other researchers.

[Documentation](https://hpi-dhc.github.io/devicely/)

[PyPi](https://pypi.org/project/devicely/)

## Getting started

To get started quickly, follow the "Getting started"-section in our docs.

https://hpi-dhc.github.io/devicely/


## Supported sensors

- [Empatica E4](https://e4.empatica.com/e4-wristband)
- [Biovotion Everion](https://www.biovotion.com/everion/)
- [1-lead ECG monitor Faros<sup>TM</sup> 180 from Bittium](https://shop.bittium.com/product/36/bittium-faros-180-solution-pack)
- [Spacelabs](https://www.spacelabshealthcare.com/products/diagnostic-cardiology/abp-monitoring/90217a/)
- [Tags (obtained from the app: TimeStamp for Android)](https://play.google.com/store/apps/details?id=gj.timestamp&hl=en)
- [Shimmer Consensys GSR](https://www.shimmersensing.com/products/gsr-optical-pulse-development-kit#specifications-tab)

## Contributors

```
* Ariane Sasso
* Arpita Kappattanavar
* Bjarne Pfitzner
* Felix Musmann
* Jost Morgenstern
* Lin Zhou
* Pascal Hecker
```

==> devicely-1.0.2.tar.gz: devicely-1.0.2/README.md <==
[![Actions Status: test](https://github.com/hpi-dhc/devicely/workflows/test/badge.svg)](https://github.com/hpi-dhc/devicely/actions/workflows/test.yml)
![Coverage Badge](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/jostmorgenstern/270a0114dfad9251945a146dd6d29fa6/raw/devicely_coverage_main.json)
[![DOI](https://zenodo.org/badge/279395106.svg)](https://zenodo.org/badge/latestdoi/{279395106})
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)

![Devicely Logo](/imgs/logo/devicely-logo.png)

devicely is a Python package for reading, anonymizing and writing data from various health monitoring sensors.
With devicely, you can read sensor data and have it easily accessible in dataframes.
You can also anonymize data and write it back using the original data format. This makes it convenient to share health sensor data with other researchers.

[Documentation](https://hpi-dhc.github.io/devicely/)

[PyPi](https://pypi.org/project/devicely/)

## Getting started

To get started quickly, follow the [quick-start guide](https://hpi-dhc.github.io/devicely/example.html#) in our documentation.

https://hpi-dhc.github.io/devicely/


## Supported sensors

- [Empatica E4](https://e4.empatica.com/e4-wristband)
- [Biovotion Everion](https://www.biovotion.com/everion/)
- [1-lead ECG monitor Faros<sup>TM</sup> 180 from Bittium](https://shop.bittium.com/product/36/bittium-faros-180-solution-pack)
- [Spacelabs](https://www.spacelabshealthcare.com/products/diagnostic-cardiology/abp-monitoring/90217a/)
- [Tags (obtained from the app: TimeStamp for Android)](https://play.google.com/store/apps/details?id=gj.timestamp&hl=en)
- [Shimmer Consensys GSR](https://www.shimmersensing.com/products/gsr-optical-pulse-development-kit#specifications-tab)

## Contributors

```
* Ariane Sasso
* Arpita Kappattanavar
* Bjarne Pfitzner
* Felix Musmann
* Jost Morgenstern
* Lin Zhou
* Pascal Hecker
```
